# FILE: mmlaunch.tcl
#
# An application which presents an interface for launching and 
# interconnecting other OOMMF applications.
#
# Last modified on: $Date: 1998/08/06 17:40:32 $
# Last modified by: $Author: dgp $

# Support libraries
package require Ow
package require Net
package require Oc
if {[catch {package require Tk 8}]} {
    package require Tk 4.1
}

wm title . "mmLaunch"
wm iconname . [wm title .]

set menubar [frame .omfMenuBar -borderwidth 2 -relief raised]

# File menu
set fmb [menubutton .omfFile -text "File" -menu .omfFile.menu -underline 0]
set fmenu [menu .omfFile.menu -tearoff 0]
$fmenu add command -label "Exit" -underline 1 -command exit

# Help menu
set hmb [menubutton .omfHelp -text "Help" -menu .omfHelp.menu -underline 0]
set hmenu [menu .omfHelp.menu -tearoff 0]
$hmenu add command -label "About" -underline 0 -state disabled
$hmenu add command -label "On Oommf..." \
        -state disabled \
        -underline 3 \
        -command [list LaunchHelp \
                [[Oc_Url FromFilename [file join [file dirname \
                [Oc_DirectPathname [info script]]] doc index.html]] ToString]]

Oc_Application SetSearchPath [list [file dirname [file dirname \
        [file dirname [Oc_DirectPathname [info script]]]]]]
proc LaunchHelp {urlstring} {
    if {[Oc_Option Get {} htmlBrowserCmd browsercmd]} {
        eval {Oc_Application Exec mmhelp} $urlstring &
    } else {
        eval $browsercmd $urlstring &
    }
}

proc DisplayHostButtons {} {
    global hframe hpanel
    # Destroy existing buttons
    foreach w [winfo children $hframe] {
        destroy $w
    }
    foreach host [Net_Host Instances] {
        if {[$host Ready]} {
            set btn [checkbutton $hframe.w$host -text [$host Cget -hostname] \
                -variable  ${host}_BtnVar \
                -anchor w \
                -command [list $host ToggleGui $hpanel]]
            pack $btn -side top -fill x
        }
    }
}
em_eventHandler new Net_Host Ready DisplayHostButtons
em_eventHandler new Net_Host delete DisplayHostButtons

# Host checkbutton frame
set hframe [frame .omfHosts -bd 4 -relief ridge]
set hpanel [frame .omfPanel -relief groove]

pack $fmb -side left -in $menubar
pack $hmb -side right -in $menubar
pack $menubar -side top -fill x
pack $hframe -side left -fill y
pack $hpanel -side left -fill both -expand 1
Ow_SetIcon .
update

# Listen for tell messages from all accounts -- they announce new threads
# Each time a new account becomes Ready create a listening Handler for it.
em_eventHandler new Net_Account Ready StartAccountListener
proc StartAccountListener {} {
    global listeners
    foreach acct [Net_Account Instances] {
        if {![info exists listeners($acct,r)]} {
            set listeners($acct,r) [em_eventHandler new $acct Readable \
                    [list HandleAccountTell $acct]]
            set listeners($acct,d) [em_eventHandler new $acct delete \
                    [list DeleteAccountListener $acct]]
        }
    }
}
proc DeleteAccountListener { acct } {
    global listeners
    if {[info exists listeners($acct,r)]} {
        $listeners($acct,r) delete
        $listeners($acct,d) delete
        unset listeners($acct,r)
        unset listeners($acct,d)
    }
}
proc HandleAccountTell { acct } {
    set message [$acct Get]
    switch -exact -- [lindex $message 0] {
        newthread {
            NewThread $acct
        }
        default {
          [em_extension ApplicationLog] Append "Bad message from account $acct:
	$message"
        }
    }
}
proc NewThread { acct } {
    global qhandler thandler
    if {[info exists qhandler($acct)]} {
        # Only one 'threads' request per account can use qhandler at a time
        after 1000 NewThread $acct
        return
    }
    set qid [$acct Send threads]
    set qhandler($acct) [em_eventHandler new $acct Reply$qid \
            [list NewThreadReply $acct]]
    set thandler($acct) [em_eventHandler new $acct Reply$qid \
            [list NewThreadTimeout $acct]]
}
proc NewThreadReply { acct } {
    global qhandler thandler
    $qhandler($acct) delete
    $thandler($acct) delete
    unset qhandler($acct)
    unset thandler($acct)
    set threads [$acct Get]
    [$acct Cget -log] Append "Received thread list: $threads"
    # create a thread for any threads on list not already represented
    # This is a really dumb way to do this!
    if {![lindex $threads 0]} {
        foreach triple [lrange $threads 1 end] {
            Net_Thread New _ -hostname [$acct Cget -hostname] \
                    -accountname [$acct Cget -accountname] \
                    -pid [lindex $triple 1] -alias [lindex $triple 0] \
                    -log [em_extension ApplicationLog]
        }
    }
}
proc NewThreadTimeout { acct } {
    global qhandler thandler
    $qhandler($acct) delete
    $thandler($acct) delete
    unset qhandler($acct)
    unset thandler($acct)
    [$acct Cget -log] Append "Timed out waiting for thread list"
}

# Create initial host list -- try to connect to account servers
set hostList localhost
Oc_Option Get LaunchInterface hostList hostList
foreach host $hostList {
    if {![string match $host* [info hostname]]} {
        Net_Account New _ -hostname $host \
                -log [em_extension ApplicationLog]
    }
}

# When any account becomes ready, get its threads
foreach ia [Net_Account Instances] {
    em_eventHandler new $ia Ready [list NewThread $ia]
}

